Crate anyinput_core
source · [−]Expand description
anyinput-core
Important Note:
- You are probably looking for the
anyinputcrate, which wraps this crate and is much more ergonomic to use.
Purpose
This is an internal helper library of anyinput.
Important Note:
anyinput crate, which wraps this crate and is much more ergonomic to use.This is an internal helper library of anyinput.